/* Copyright 2004 Jetro Lauha - http://iki.fi/jetro/
 *
 * $Id: testlevel.as,v 1.12 2004/11/09 21:04:12 tonic Exp $
 * $Revision: 1.12 $
 */

/* Note: playSound function is undocumented as it is currently
 *       only temporarily as it is.
 */

// Game executable version this script has been written for:
const int SCRIPT_GAME_VERSION = int(0x000400);

const int GROUNDHIT_TIME = 4000;
const int MAX_TIME = 15000;
const float INITIAL_GRAV = -1.0;

uint mTime;
int screenWidth, screenHeight;
uint frame = 0;

int timeLeft = 0;
int score = 0;
int objectshit = 0;

UIFont *medFont, *smallFont;
uint medFontHeight, smallFontHeight;

PhysicsObject *objHead;

PhysicsObject *objH1, *objH2, *objH3, *objH4, *objH5, *objH6;

bool finished = false;
bool aborted = false;
bool hitground = false;
uint hitgroundtime = 0;


// Called once on level initialization.
void onInit()
{
    requireGameVersion(SCRIPT_GAME_VERSION);
    screenWidth = getScreenWidth();
    screenHeight = getScreenHeight();
    medFont = getFont("medium");
    smallFont = getFont("small");
    medFontHeight = medFont->getFontHeight();
    smallFontHeight = smallFont->getFontHeight();

    setGravity(0, 0, INITIAL_GRAV);

    // Ragdoll head
    objHead = findObject("Head");

    objH1 = findObject("H1");
    objH2 = findObject("H2");
    objH3 = findObject("H3");
    objH4 = findObject("H4");
    objH5 = findObject("H5");
    objH6 = findObject("H6");
}


// Called once for each game logic update before the physics update.
// Parameter 'time' is the simulation time in milliseconds.
void onUpdate(uint time)
{
    ++frame;
    if (!aborted and !finished) mTime = time;

    float x = 0;
    float y = 0;
    float z = 0;
    objHead->getPosition(x, y, z);
    
    if (z < -95 and !hitground)
    {
    	hitground=true;
    	hitgroundtime = mTime;
    }

    if (z < -100 )
    {
        aborted = true;
        setGameState(GAMESTATE_ABORTED);
    }
    
    if (hitground)
    	timeLeft = (int(hitgroundtime)+int(GROUNDHIT_TIME)) - int(mTime);
    else
    	timeLeft = int(MAX_TIME) - int(mTime);
    
    if (timeLeft < 0)
        timeLeft = 0;
    if (timeLeft == 0 && !aborted)
    {
    	if (hitground)
    	{
	        finished = true;
	        setGameState(GAMESTATE_FINISHED);
		}
		else
    	{
	        aborted = true;
	        setGameState(GAMESTATE_ABORTED);
		}
		
    }
	
	float newGrav=INITIAL_GRAV;
	newGrav-=float(randomDouble());
    
    setGravity(0, 0, newGrav);
   
}


// Called when there is a collision between the two given objects.
// Returns true to create contacts or false to ignore collision.
bool onCollision(PhysicsObject *o1, PhysicsObject *o2)
{
	bool headhit=false;
	PhysicsObject *pObject;
	
	if (o1 == objHead)
	{
		headhit=true;
		pObject=o2;
	}
	if (o2 == objHead)
	{
		headhit=true;
		pObject=o1;
	}
	
	if (headhit) 
	{
		score++;
		bool isPhys=pObject->isPhysicsEnabled();
		if (isPhys)
		{
			objectshit++;
			score+=5;  //object hit with head
		}
	}
	
	
    
    // generate collision
    return true;
}


// Called when the game view is rendered.
// Might happen more or less frequently than update calls.
void onRender()
{
    const float gap = 70;
    
    if (mTime < 4000)
    {
        float x = float(screenWidth / 2);
        float y = gap;
        x += float(cos(double(mTime) * 0.01) * 4);
        y += float(sin(double(mTime) * 0.01) * 4);
        //x += float(randomDouble() * 2 - 1);
        //y += float(randomDouble() * 2 - 1);
        medFont->drawString(x, y,
                            UIFONT_ALIGN_HORIZ_CENTER | UIFONT_ALIGN_BOTTOM,
                            "Torniturvat ModEd V0.3 by Silencer");
                            
	    smallFont->drawString(x, 130,UIFONT_ALIGN_HORIZ_CENTER, "You got 15 secs to hit ground. After groundhit you got 4 more secs.");
	    smallFont->drawString(x, float(130+smallFontHeight),UIFONT_ALIGN_HORIZ_CENTER, "Headhits count 1 score. Headhits to physics objects count 5 score.");
	    smallFont->drawString(x, float(130+(2*smallFontHeight)),UIFONT_ALIGN_HORIZ_CENTER, "(greetz to GynZi 4 the cool scenary)");
                            
                            
    }
	
	//drawPos();

    // draw score
    const float x = float(screenWidth) - gap;
    medFont->drawString(x, gap, UIFONT_ALIGN_RIGHT, bstrFormat(score));
    smallFont->drawString(x, gap + float(medFontHeight),
                          UIFONT_ALIGN_RIGHT, "Score");

    medFont->drawString(x-50, gap, UIFONT_ALIGN_RIGHT, bstrFormat(objectshit));
    smallFont->drawString(x-50, gap + float(medFontHeight),
                          UIFONT_ALIGN_RIGHT, "ObjHit");
                          
                          

    drawTime();

    if (aborted)
        drawFailure();
    if (finished)
        drawVictory();

	if (hitground)
		drawHitGound();        
}

void drawPos()
{
	float posx = 0;
	float posy = 0;
	float posz = 0;
  	objHead->getPosition(posx, posy, posz);
	
    smallFont->drawString(5,10,UIFONT_ALIGN_DEFAULT, "x");
    smallFont->drawString(5,20,UIFONT_ALIGN_DEFAULT, "y");
    smallFont->drawString(5,30,UIFONT_ALIGN_DEFAULT, "z");
    
    smallFont->drawString(15,10,UIFONT_ALIGN_DEFAULT, bstrFormat(posx));
    smallFont->drawString(15,20,UIFONT_ALIGN_DEFAULT, bstrFormat(posy));
    smallFont->drawString(15,30,UIFONT_ALIGN_DEFAULT, bstrFormat(posz));
}

void drawHitGound()
{
    float x = float(screenWidth / 2);
    float y = 70;
    x += float(cos(double(mTime) * 0.01) * 4);
    y += float(sin(double(mTime) * 0.01) * 4);
    medFont->drawString(x, y, UIFONT_ALIGN_HORIZ_CENTER, "Ground Hit");
}

void drawTime()
{
	//time Taken
	if (true)
	{
	    const float x = 180, y = 70;
	    int fracs = (int(mTime) / 10) % 100;
	    int seconds = int(mTime) / 1000;
	    bstr fracsStr = (fracs < 10 ? "0" : "") + bstrFormat(fracs);
	
	    medFont->drawString(x, y, UIFONT_ALIGN_HORIZ_CENTER, ":");
	    medFont->drawString(x - 4, y, UIFONT_ALIGN_RIGHT, bstrFormat(seconds));
	    medFont->drawString(x + 4, y, UIFONT_ALIGN_DEFAULT, fracsStr);
	    smallFont->drawString(x, y + float(medFontHeight),
	                          UIFONT_ALIGN_HORIZ_CENTER, "Time Used");
	
	}
	
	//timeLeft
	if (true)
	{
	    const float x = 100, y = 70;
	    int fracs = (timeLeft / 10) % 100;
	    int seconds = timeLeft / 1000;
	    bstr fracsStr = (fracs < 10 ? "0" : "") + bstrFormat(fracs);
	
	    medFont->drawString(x, y, UIFONT_ALIGN_HORIZ_CENTER, ":");
	    medFont->drawString(x - 4, y, UIFONT_ALIGN_RIGHT, bstrFormat(seconds));
	    medFont->drawString(x + 4, y, UIFONT_ALIGN_DEFAULT, fracsStr);
	    smallFont->drawString(x, y + float(medFontHeight),
	                          UIFONT_ALIGN_HORIZ_CENTER, "Time Left");
	}
}


void drawFailure()
{
    medFont->drawString(float(screenWidth / 2), float(screenHeight / 2),
                        UIFONT_ALIGN_HORIZ_CENTER | UIFONT_ALIGN_VERT_CENTER,
                        "You Failed!");
}


void drawVictory()
{
    medFont->drawString(float(screenWidth / 2), float(screenHeight / 2),
                        UIFONT_ALIGN_HORIZ_CENTER | UIFONT_ALIGN_VERT_CENTER,
                        "Finished!");
}
